
# djangoappgen

Un générateur de base pour créer automatiquement des applications Django avec la structure standard (`models.py`, `views.py`, etc.).

## Installation

```bash
pip install djangoappgen
